==> monocdk-1.185.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/location/CfnRouteCalculatorProps.java <==
package software.amazon.awscdk.services.location;

/**
 * Properties for defining a `CfnRouteCalculator`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.location.*;
 * CfnRouteCalculatorProps cfnRouteCalculatorProps = CfnRouteCalculatorProps.builder()
 *         .calculatorName("calculatorName")
 *         .dataSource("dataSource")
 *         // the properties below are optional
 *         .description("description")
 *         .pricingPlan("pricingPlan")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.72.0 (build 4b8828b)", date = "2022-12-27T20:29:05.842Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "monocdk.aws_location.CfnRouteCalculatorProps")
@software.amazon.jsii.Jsii.Proxy(CfnRouteCalculatorProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnRouteCalculatorProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the route calculator resource.
     * <p>
     * Requirements:
     * <p>
     * <ul>
     * <li>Can use alphanumeric characters (A–Z, a–z, 0–9) , hyphens (-), periods (.), and underscores (_).</li>
     * <li>Must be a unique route calculator resource name.</li>
     * <li>No spaces allowed. For example, <code>ExampleRouteCalculator</code> .</li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getCalculatorName();

    /**
     * Specifies the data provider of traffic and road network data.
     * <p>
     * <blockquote>
     * <p>
     * This field is case-sensitive. Enter the valid values as shown. For example, entering <code>HERE</code> returns an error.
     * <p>
     * </blockquote>
     * <p>
     * Valid values include:
     * <p>
     * <ul>
     * <li><code>Esri</code></li>
     * <li><code>Here</code></li>
     * </ul>
     * <p>
     * For more information about data providers, see the <a href="https://docs.aws.amazon.com/location/latest/developerguide/what-is-data-provider.html">Amazon Location Service data providers page</a> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDataSource();

    /**
     * The optional description for the route calculator resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return null;
    }

    /**
     * No longer used. If included, the only allowed value is `RequestBasedUsage` .
     * <p>
     * <em>Allowed Values</em> : <code>RequestBasedUsage</code>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPricingPlan() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnRouteCalculatorProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnRouteCalculatorProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnRouteCalculatorProps> {
        java.lang.String calculatorName;
        java.lang.String dataSource;
        java.lang.String description;
        java.lang.String pricingPlan;

        /**
         * Sets the value of {@link CfnRouteCalculatorProps#getCalculatorName}
         * @param calculatorName The name of the route calculator resource. This parameter is required.
         *                       Requirements:
         *                       <p>
         *                       <ul>
         *                       <li>Can use alphanumeric characters (A–Z, a–z, 0–9) , hyphens (-), periods (.), and underscores (_).</li>
         *                       <li>Must be a unique route calculator resource name.</li>
         *                       <li>No spaces allowed. For example, <code>ExampleRouteCalculator</code> .</li>
         *                       </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder calculatorName(java.lang.String calculatorName) {
            this.calculatorName = calculatorName;
            return this;
        }

        /**
         * Sets the value of {@link CfnRouteCalculatorProps#getDataSource}
         * @param dataSource Specifies the data provider of traffic and road network data. This parameter is required.
         *                   <blockquote>
         *                   <p>
         *                   This field is case-sensitive. Enter the valid values as shown. For example, entering <code>HERE</code> returns an error.
         *                   <p>
         *                   </blockquote>
         *                   <p>
         *                   Valid values include:
         *                   <p>
         *                   <ul>
         *                   <li><code>Esri</code></li>
         *                   <li><code>Here</code></li>
         *                   </ul>
         *                   <p>
         *                   For more information about data providers, see the <a href="https://docs.aws.amazon.com/location/latest/developerguide/what-is-data-provider.html">Amazon Location Service data providers page</a> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder dataSource(java.lang.String dataSource) {
            this.dataSource = dataSource;
            return this;
        }

        /**
         * Sets the value of {@link CfnRouteCalculatorProps#getDescription}
         * @param description The optional description for the route calculator resource.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link CfnRouteCalculatorProps#getPricingPlan}
         * @param pricingPlan No longer used. If included, the only allowed value is `RequestBasedUsage` .
         *                    <em>Allowed Values</em> : <code>RequestBasedUsage</code>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder pricingPlan(java.lang.String pricingPlan) {
            this.pricingPlan = pricingPlan;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRouteCalculatorProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnRouteCalculatorProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnRouteCalculatorProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnRouteCalculatorProps {
        private final java.lang.String calculatorName;
        private final java.lang.String dataSource;
        private final java.lang.String description;
        private final java.lang.String pricingPlan;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.calculatorName = software.amazon.jsii.Kernel.get(this, "calculatorName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.dataSource = software.amazon.jsii.Kernel.get(this, "dataSource", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.pricingPlan = software.amazon.jsii.Kernel.get(this, "pricingPlan", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.calculatorName = java.util.Objects.requireNonNull(builder.calculatorName, "calculatorName is required");
            this.dataSource = java.util.Objects.requireNonNull(builder.dataSource, "dataSource is required");
            this.description = builder.description;
            this.pricingPlan = builder.pricingPlan;
        }

        @Override
        public final java.lang.String getCalculatorName() {
            return this.calculatorName;
        }

        @Override
        public final java.lang.String getDataSource() {
            return this.dataSource;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.lang.String getPricingPlan() {
            return this.pricingPlan;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("calculatorName", om.valueToTree(this.getCalculatorName()));
            data.set("dataSource", om.valueToTree(this.getDataSource()));
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getPricingPlan() != null) {
                data.set("pricingPlan", om.valueToTree(this.getPricingPlan()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("monocdk.aws_location.CfnRouteCalculatorProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnRouteCalculatorProps.Jsii$Proxy that = (CfnRouteCalculatorProps.Jsii$Proxy) o;

            if (!calculatorName.equals(that.calculatorName)) return false;
            if (!dataSource.equals(that.dataSource)) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            return this.pricingPlan != null ? this.pricingPlan.equals(that.pricingPlan) : that.pricingPlan == null;
        }

        @Override
        public final int hashCode() {
            int result = this.calculatorName.hashCode();
            result = 31 * result + (this.dataSource.hashCode());
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.pricingPlan != null ? this.pricingPlan.hashCode() : 0);
            return result;
        }
    }
}

==> monocdk-1.188.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/location/CfnRouteCalculatorProps.java <==
package software.amazon.awscdk.services.location;

/**
 * Properties for defining a `CfnRouteCalculator`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.location.*;
 * CfnRouteCalculatorProps cfnRouteCalculatorProps = CfnRouteCalculatorProps.builder()
 *         .calculatorName("calculatorName")
 *         .dataSource("dataSource")
 *         // the properties below are optional
 *         .description("description")
 *         .pricingPlan("pricingPlan")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.72.0 (build 4b8828b)", date = "2023-01-11T14:45:05.833Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "monocdk.aws_location.CfnRouteCalculatorProps")
@software.amazon.jsii.Jsii.Proxy(CfnRouteCalculatorProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnRouteCalculatorProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the route calculator resource.
     * <p>
     * Requirements:
     * <p>
     * <ul>
     * <li>Can use alphanumeric characters (A–Z, a–z, 0–9) , hyphens (-), periods (.), and underscores (_).</li>
     * <li>Must be a unique route calculator resource name.</li>
     * <li>No spaces allowed. For example, <code>ExampleRouteCalculator</code> .</li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getCalculatorName();

    /**
     * Specifies the data provider of traffic and road network data.
     * <p>
     * <blockquote>
     * <p>
     * This field is case-sensitive. Enter the valid values as shown. For example, entering <code>HERE</code> returns an error.
     * <p>
     * </blockquote>
     * <p>
     * Valid values include:
     * <p>
     * <ul>
     * <li><code>Esri</code> – For additional information about <a href="https://docs.aws.amazon.com/location/latest/developerguide/esri.html">Esri</a> 's coverage in your region of interest, see <a href="https://docs.aws.amazon.com/https://doc.arcgis.com/en/arcgis-online/reference/network-coverage.htm">Esri details on street networks and traffic coverage</a> .</li>
     * </ul>
     * <p>
     * Route calculators that use Esri as a data source only calculate routes that are shorter than 400 km.
     * <p>
     * <ul>
     * <li><code>Grab</code> – Grab provides routing functionality for Southeast Asia. For additional information about <a href="https://docs.aws.amazon.com/location/latest/developerguide/grab.html">GrabMaps</a> ' coverage, see <a href="https://docs.aws.amazon.com/location/latest/developerguide/grab.html#grab-coverage-area">GrabMaps countries and areas covered</a> .</li>
     * <li><code>Here</code> – For additional information about <a href="https://docs.aws.amazon.com/location/latest/developerguide/HERE.html">HERE Technologies</a> ' coverage in your region of interest, see <a href="https://docs.aws.amazon.com/https://developer.here.com/documentation/routing-api/dev_guide/topics/coverage/car-routing.html">HERE car routing coverage</a> and <a href="https://docs.aws.amazon.com/https://developer.here.com/documentation/routing-api/dev_guide/topics/coverage/truck-routing.html">HERE truck routing coverage</a> .</li>
     * </ul>
     * <p>
     * For additional information , see <a href="https://docs.aws.amazon.com/location/latest/developerguide/what-is-data-provider.html">Data providers</a> on the <em>Amazon Location Service Developer Guide</em> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDataSource();

    /**
     * The optional description for the route calculator resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return null;
    }

    /**
     * No longer used. If included, the only allowed value is `RequestBasedUsage` .
     * <p>
     * <em>Allowed Values</em> : <code>RequestBasedUsage</code>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPricingPlan() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnRouteCalculatorProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnRouteCalculatorProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnRouteCalculatorProps> {
        java.lang.String calculatorName;
        java.lang.String dataSource;
        java.lang.String description;
        java.lang.String pricingPlan;

        /**
         * Sets the value of {@link CfnRouteCalculatorProps#getCalculatorName}
         * @param calculatorName The name of the route calculator resource. This parameter is required.
         *                       Requirements:
         *                       <p>
         *                       <ul>
         *                       <li>Can use alphanumeric characters (A–Z, a–z, 0–9) , hyphens (-), periods (.), and underscores (_).</li>
         *                       <li>Must be a unique route calculator resource name.</li>
         *                       <li>No spaces allowed. For example, <code>ExampleRouteCalculator</code> .</li>
         *                       </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder calculatorName(java.lang.String calculatorName) {
            this.calculatorName = calculatorName;
            return this;
        }

        /**
         * Sets the value of {@link CfnRouteCalculatorProps#getDataSource}
         * @param dataSource Specifies the data provider of traffic and road network data. This parameter is required.
         *                   <blockquote>
         *                   <p>
         *                   This field is case-sensitive. Enter the valid values as shown. For example, entering <code>HERE</code> returns an error.
         *                   <p>
         *                   </blockquote>
         *                   <p>
         *                   Valid values include:
         *                   <p>
         *                   <ul>
         *                   <li><code>Esri</code> – For additional information about <a href="https://docs.aws.amazon.com/location/latest/developerguide/esri.html">Esri</a> 's coverage in your region of interest, see <a href="https://docs.aws.amazon.com/https://doc.arcgis.com/en/arcgis-online/reference/network-coverage.htm">Esri details on street networks and traffic coverage</a> .</li>
         *                   </ul>
         *                   <p>
         *                   Route calculators that use Esri as a data source only calculate routes that are shorter than 400 km.
         *                   <p>
         *                   <ul>
         *                   <li><code>Grab</code> – Grab provides routing functionality for Southeast Asia. For additional information about <a href="https://docs.aws.amazon.com/location/latest/developerguide/grab.html">GrabMaps</a> ' coverage, see <a href="https://docs.aws.amazon.com/location/latest/developerguide/grab.html#grab-coverage-area">GrabMaps countries and areas covered</a> .</li>
         *                   <li><code>Here</code> – For additional information about <a href="https://docs.aws.amazon.com/location/latest/developerguide/HERE.html">HERE Technologies</a> ' coverage in your region of interest, see <a href="https://docs.aws.amazon.com/https://developer.here.com/documentation/routing-api/dev_guide/topics/coverage/car-routing.html">HERE car routing coverage</a> and <a href="https://docs.aws.amazon.com/https://developer.here.com/documentation/routing-api/dev_guide/topics/coverage/truck-routing.html">HERE truck routing coverage</a> .</li>
         *                   </ul>
         *                   <p>
         *                   For additional information , see <a href="https://docs.aws.amazon.com/location/latest/developerguide/what-is-data-provider.html">Data providers</a> on the <em>Amazon Location Service Developer Guide</em> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder dataSource(java.lang.String dataSource) {
            this.dataSource = dataSource;
            return this;
        }

        /**
         * Sets the value of {@link CfnRouteCalculatorProps#getDescription}
         * @param description The optional description for the route calculator resource.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link CfnRouteCalculatorProps#getPricingPlan}
         * @param pricingPlan No longer used. If included, the only allowed value is `RequestBasedUsage` .
         *                    <em>Allowed Values</em> : <code>RequestBasedUsage</code>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder pricingPlan(java.lang.String pricingPlan) {
            this.pricingPlan = pricingPlan;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRouteCalculatorProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnRouteCalculatorProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnRouteCalculatorProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnRouteCalculatorProps {
        private final java.lang.String calculatorName;
        private final java.lang.String dataSource;
        private final java.lang.String description;
        private final java.lang.String pricingPlan;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.calculatorName = software.amazon.jsii.Kernel.get(this, "calculatorName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.dataSource = software.amazon.jsii.Kernel.get(this, "dataSource", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.pricingPlan = software.amazon.jsii.Kernel.get(this, "pricingPlan", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.calculatorName = java.util.Objects.requireNonNull(builder.calculatorName, "calculatorName is required");
            this.dataSource = java.util.Objects.requireNonNull(builder.dataSource, "dataSource is required");
            this.description = builder.description;
            this.pricingPlan = builder.pricingPlan;
        }

        @Override
        public final java.lang.String getCalculatorName() {
            return this.calculatorName;
        }

        @Override
        public final java.lang.String getDataSource() {
            return this.dataSource;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.lang.String getPricingPlan() {
            return this.pricingPlan;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("calculatorName", om.valueToTree(this.getCalculatorName()));
            data.set("dataSource", om.valueToTree(this.getDataSource()));
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getPricingPlan() != null) {
                data.set("pricingPlan", om.valueToTree(this.getPricingPlan()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("monocdk.aws_location.CfnRouteCalculatorProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnRouteCalculatorProps.Jsii$Proxy that = (CfnRouteCalculatorProps.Jsii$Proxy) o;

            if (!calculatorName.equals(that.calculatorName)) return false;
            if (!dataSource.equals(that.dataSource)) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            return this.pricingPlan != null ? this.pricingPlan.equals(that.pricingPlan) : that.pricingPlan == null;
        }

        @Override
        public final int hashCode() {
            int result = this.calculatorName.hashCode();
            result = 31 * result + (this.dataSource.hashCode());
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.pricingPlan != null ? this.pricingPlan.hashCode() : 0);
            return result;
        }
    }
}
